@@ -3,14 +3,13 @@
 """
 
 import networkx as nx
-import itertools
-import types
 import logging
 
 from fhir2dataset.timer import timing
 
 logger = logging.getLogger(__name__)
 
+
 @timing
 def join_path(graph: nx.Graph) -> list:
     """transforms the query graph into an Eulerian graph in order to be able to find an Eulerian path in it.
@@ -23,12 +22,13 @@ def join_path(graph: nx.Graph) -> list:
 
     Returns:
         list -- List of tuples indicating the successive joints to be made
-    """
+    """  # noqa
     euler_graph = nx.eulerize(graph)
     euler_path = list(nx.eulerian_path(euler_graph))
     path = clean_euler_path(euler_path)
     return path
 
+
 @timing
 def clean_euler_path(eulerian_path: list) -> list:
     """Cleans a Eulerian path so that each edge (not directed) appears only once in the list. If a edge appears more than once, only the first occurrence is kept.
@@ -38,7 +38,7 @@ def clean_euler_path(eulerian_path: list) -> list:
 
     Returns:
         list -- cleaned Eulerian path
-    """
+    """  # noqa
     path = []
     while eulerian_path:
         edge = eulerian_path.pop(0)
